@@ -5,9 +5,9 @@ require_once 'Horde/Identity.php';
 
 /**
  * Horde Kronolith driver for the Kolab IMAP Server.
- * Copyright 2004-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
- * $Horde: kronolith/lib/Driver/kolab.php,v 1.16.2.26 2008/04/30 21:33:20 chuck Exp $
+ * $Horde: kronolith/lib/Driver/kolab.php,v 1.16.2.30 2009/01/06 15:24:45 jan Exp $
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -169,18 +169,18 @@ class Kronolith_Driver_kolab extends Kronolith_Driver {
      *
      * @return mixed  True or a PEAR_Error on failure.
      */
-    function deleteEvent($eventID)
+    function deleteEvent($eventID, $silent = false)
     {
-        return $this->_wrapper->deleteEvent($eventID);
+        return $this->_wrapper->deleteEvent($eventID, $silent);
     }
 }
 
 /**
  * Horde Kronolith wrapper to distinguish between both Kolab driver implementations.
  *
- * $Horde: kronolith/lib/Driver/kolab.php,v 1.16.2.26 2008/04/30 21:33:20 chuck Exp $
+ * $Horde: kronolith/lib/Driver/kolab.php,v 1.16.2.30 2009/01/06 15:24:45 jan Exp $
  *
- * Copyright 2004-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -220,7 +220,7 @@ class Kronolith_Driver_kolab_wrapper {
 
 /**
  * Horde Kronolith driver for the Kolab IMAP Server.
- * Copyright 2004-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -500,6 +500,7 @@ class Kronolith_Driver_kolab_wrapper_old extends Kronolith_Driver_kolab_wrapper
         }
 
         switch ($event->status) {
+        case KRONOLITH_STATUS_FREE:
         case KRONOLITH_STATUS_CANCELLED:
             $this->_kolab->setVal('show-time-as', 'free');
             break;
@@ -727,7 +728,7 @@ class Kronolith_Driver_kolab_wrapper_old extends Kronolith_Driver_kolab_wrapper
      *
      * @return mixed  True or a PEAR_Error on failure.
      */
-    function deleteEvent($eventID)
+    function deleteEvent($eventID, $silent = false)
     {
         $this->connect();
 
@@ -748,9 +749,11 @@ class Kronolith_Driver_kolab_wrapper_old extends Kronolith_Driver_kolab_wrapper
         }
 
         /* Notify about the deleted event. */
-        $result = Kronolith::sendNotification($event, 'delete');
-        if (is_a($result, 'PEAR_Error')) {
-            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+        if (!$silent) {
+            $result = Kronolith::sendNotification($event, 'delete');
+            if (is_a($result, 'PEAR_Error')) {
+                Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+            }
         }
     }
 
@@ -786,7 +789,7 @@ class Kronolith_Event_kolab_old extends Kronolith_Event {
         $status = $kolab->getVal('show-time-as');
         switch ($status) {
         case 'free':
-            $this->status = KRONOLITH_STATUS_CANCELLED;
+            $this->status = KRONOLITH_STATUS_FREE;
             break;
 
         case 'tentative':
@@ -947,7 +950,7 @@ class Kronolith_Event_kolab_old extends Kronolith_Event {
 
 /**
  * Horde Kronolith driver for the Kolab IMAP Server.
- * Copyright 2004-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -1293,6 +1296,8 @@ class Kronolith_Driver_kolab_wrapper_new extends Kronolith_Driver_kolab_wrapper
      */
     function move($eventId, $newCalendar)
     {
+        $event = &$this->getEvent($eventId);
+
         $result = $this->synchronize();
         if (is_a($result, 'PEAR_Error')) {
             return $result;
@@ -1312,6 +1317,12 @@ class Kronolith_Driver_kolab_wrapper_new extends Kronolith_Driver_kolab_wrapper
             Kolab::triggerFreeBusyUpdate($this->_store->parseFolder($newCalendar));
         }
 
+        /* Log the moving of this item in the history log. */
+        $uid = $event->getUID();
+        $history = &Horde_History::singleton();
+        $history->log('kronolith:' . $event->getCalendar() . ':' . $uid, array('action' => 'delete'), true);
+        $history->log('kronolith:' . $newCalendar . ':' . $uid, array('action' => 'add'), true);
+
         return $result;
     }
 
@@ -1361,7 +1372,7 @@ class Kronolith_Driver_kolab_wrapper_new extends Kronolith_Driver_kolab_wrapper
      *
      * @return mixed  True or a PEAR_Error on failure.
      */
-    function deleteEvent($eventId)
+    function deleteEvent($eventId, $silent = false)
     {
         $result = $this->synchronize();
         if (is_a($result, 'PEAR_Error')) {
@@ -1376,9 +1387,11 @@ class Kronolith_Driver_kolab_wrapper_new extends Kronolith_Driver_kolab_wrapper
 
         if ($this->_store->delete($eventId)) {
             // Notify about the deleted event.
-            $result = Kronolith::sendNotification($event, 'delete');
-            if (is_a($result, 'PEAR_Error')) {
-                Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+            if (!$silent) {
+                $result = Kronolith::sendNotification($event, 'delete');
+                if (is_a($result, 'PEAR_Error')) {
+                    Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+                }
             }
 
             /* Log the deletion of this item in the history log. */
@@ -1446,7 +1459,7 @@ class Kronolith_Event_kolab_new extends Kronolith_Event {
         if (isset($event['show-time-as'])) {
             switch ($event['show-time-as']) {
                 case 'free':
-                    $this->status = KRONOLITH_STATUS_CANCELLED;
+                    $this->status = KRONOLITH_STATUS_FREE;
                     break;
 
                 case 'tentative':
@@ -1556,6 +1569,7 @@ class Kronolith_Event_kolab_new extends Kronolith_Event {
         $event['_is_all_day'] = $this->isAllDay();
 
         switch ($this->status) {
+        case KRONOLITH_STATUS_FREE:
         case KRONOLITH_STATUS_CANCELLED:
             $event['show-time-as'] = 'free';
             break;
