@@ -3,7 +3,7 @@
  * The Kronolith_Driver_sql:: class implements the Kronolith_Driver
  * API for a SQL backend.
  *
- * $Horde: kronolith/lib/Driver/sql.php,v 1.136.2.36 2008/05/14 19:41:02 chuck Exp $
+ * $Horde: kronolith/lib/Driver/sql.php,v 1.136.2.44 2009/03/06 18:12:09 jan Exp $
  *
  * @author  Luc Saillard <luc.saillard@fr.alcove.com>
  * @author  Chuck Hagenbuch <chuck@horde.org>
@@ -37,6 +37,8 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
 
     function listAlarms($date, $fullevent = false)
     {
+        require_once 'Date/Calc.php';
+
         $allevents = $this->listEvents($date, null, true);
         if (is_a($allevents, 'PEAR_Error')) {
             return $allevents;
@@ -65,12 +67,22 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
                     $start = new Horde_Date($next);
                     $start->min -= $event->getAlarm();
                     $start->correct();
+                    $diff = Date_Calc::dateDiff($event->start->mday,
+                                                $event->start->month,
+                                                $event->start->year,
+                                                $event->end->mday,
+                                                $event->end->month,
+                                                $event->end->year);
+                    if ($diff == -1) {
+                        $diff = 0;
+                    }
                     $end = new Horde_Date(array('year' => $next->year,
                                                 'month' => $next->month,
-                                                'mday' => $next->mday,
+                                                'mday' => $next->mday + $diff,
                                                 'hour' => $event->end->hour,
                                                 'min' => $event->end->min,
                                                 'sec' => $event->end->sec));
+                    $end->correct();
                     if ($start->compareDateTime($date) <= 0 &&
                         $date->compareDateTime($end) <= -1) {
                         if ($fullevent) {
@@ -142,6 +154,16 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
             }
         }
 
+        if (!empty($query->creatorID)) {
+            $binds = Horde_SQL::buildClause($this->_db, 'event_creator_id', '=', $query->creatorID, true);
+            if (is_array($binds)) {
+                $cond .= $binds[0] . ' AND ';
+                $values = array_merge($values, $binds[1]);
+            } else {
+                $cond .= $binds;
+            }
+        }
+
         if ($cond == '((') {
             $cond = '';
         } else {
@@ -197,7 +219,7 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
 
         $event = $this->_db->getRow($query, $values, DB_FETCHMODE_ASSOC);
         if (is_a($event, 'PEAR_Error')) {
-            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+            Horde::logMessage($event, __FILE__, __LINE__, PEAR_LOG_ERR);
             return $event;
         }
 
@@ -221,19 +243,18 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
      */
     function listEvents($startDate = null, $endDate = null, $hasAlarm = false)
     {
-        if (!isset($endDate)) {
+        if (empty($endDate)) {
             $endInterval = new Horde_Date(array('mday' => 31, 'month' => 12, 'year' => 9999));
         } else {
             list($endInterval->mday, $endInterval->month, $endInterval->year) = explode('/', Date_Calc::nextDay($endDate->mday, $endDate->month, $endDate->year, '%d/%m/%Y'));
         }
 
         $startInterval = null;
-        if (isset($startDate)) {
-            if ($startDate === 0) {
-                $startInterval = new Horde_Date(array('mday' => 1, 'month' => 1, 'year' => 0000));
-            } else {
-                $startInterval = new Horde_Date($startDate);
-            }
+        if (empty($startDate)) {
+            $startInterval = new Horde_Date(array('mday' => 1, 'month' => 1,
+                                                  'year' => 0000));
+        } else {
+            $startInterval = new Horde_Date($startDate);
             if ($startInterval->month == 0) {
                 $startInterval->month = 1;
             }
@@ -584,6 +605,12 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
      */
     function move($eventId, $newCalendar)
     {
+        /* Fetch the event for later use. */
+        $event = &$this->getEvent($eventId);
+        if (is_a($event, 'PEAR_Error')) {
+            return $event;
+        }
+
         $query = 'UPDATE ' . $this->_params['table'] . ' SET calendar_id = ? WHERE calendar_id = ? AND event_id = ?';
         $values = array($newCalendar, $this->_calendar, $eventId);
 
@@ -599,6 +626,14 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
             return $result;
         }
 
+        /* Log the moving of this item in the history log. */
+        $uid = $event->getUID();
+        if ($uid) {
+            $history = &Horde_History::singleton();
+            $history->log('kronolith:' . $this->_calendar . ':' . $uid, array('action' => 'delete'), true);
+            $history->log('kronolith:' . $newCalendar . ':' . $uid, array('action' => 'add'), true);
+        }
+
         return true;
     }
 
@@ -626,10 +661,12 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
      * Delete an event.
      *
      * @param string $eventId  The ID of the event to delete.
+     * @param boolean $silent  Don't send notifications, used when deleting
+     *                         events in bulk from maintenance tasks.
      *
      * @return mixed  True or a PEAR_Error on failure.
      */
-    function deleteEvent($eventId)
+    function deleteEvent($eventId, $silent = false)
     {
         /* Fetch the event for later use. */
         $event = &$this->getEvent($eventId);
@@ -657,18 +694,19 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
             $history->log('kronolith:' . $this->_calendar . ':' . $event->getUID(), array('action' => 'delete'), true);
         }
 
-        /* Remove and pending alarms. */
+        /* Remove any pending alarms. */
         if (@include_once 'Horde/Alarm.php') {
             $alarm = Horde_Alarm::factory();
             $alarm->delete($event->getUID());
         }
 
         /* Notify about the deleted event. */
-        $result = Kronolith::sendNotification($event, 'delete');
-        if (is_a($result, 'PEAR_Error')) {
-            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+        if (!$silent) {
+            $result = Kronolith::sendNotification($event, 'delete');
+            if (is_a($result, 'PEAR_Error')) {
+                Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+            }
         }
-
         return true;
     }
 
@@ -698,7 +736,8 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
         /* Connect to the SQL server using the supplied parameters. */
         require_once 'DB.php';
         $this->_write_db = &DB::connect($this->_params,
-                                        array('persistent' => !empty($this->_params['persistent'])));
+                                        array('persistent' => !empty($this->_params['persistent']),
+                                              'ssl' => !empty($this->_params['ssl'])));
         if (is_a($this->_write_db, 'PEAR_Error')) {
             return $this->_write_db;
         }
@@ -709,7 +748,8 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
         if (!empty($this->_params['splitread'])) {
             $params = array_merge($this->_params, $this->_params['read']);
             $this->_db = &DB::connect($params,
-                                      array('persistent' => !empty($params['persistent'])));
+                                      array('persistent' => !empty($params['persistent']),
+                                            'ssl' => !empty($params['ssl'])));
             if (is_a($this->_db, 'PEAR_Error')) {
                 return $this->_db;
             }
@@ -807,9 +847,7 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
         }
 
         foreach (array_keys($shares) as $calendar) {
-            $ids = Kronolith::listEventIds(0,
-                                   new Horde_Date(array('year' => 9999, 'month' => 12, 'day' => 31)),
-                                   $calendar);
+            $ids = Kronolith::listEventIds(null, null, $calendar);
             if (is_a($ids, 'PEAR_Error')) {
                 return $ids;
             }
